import { chainToPlatform, chains, decimals, explorer, finality, isChain, nativeChainIds, rpc, toChainId, } from "@wormhole-foundation/sdk-base";
import { toNative } from "./address";
import { getContracts } from "./contracts";
import { isSigner } from "./signer";
import { UniversalAddress } from "./universalAddress";
export function isTokenId(thing) {
    return (typeof thing === "object" &&
        typeof thing.address !== undefined &&
        isChain(thing.chain));
}
export function nativeChainAddress(s, a) {
    let chain;
    let address;
    // its a chain address
    if (a) {
        // We might be passed a universal address as a string
        // First try to decode it as native, otherwise try
        // to decode it as universal and convert it to native
        chain = s;
        try {
            address = toNative(chain, a);
        }
        catch {
            address = UniversalAddress.instanceof(a)
                ? a.toNative(chain)
                : new UniversalAddress(a).toNative(chain);
        }
    }
    else if (isSigner(s)) {
        chain = s.chain();
        address = toNative(s.chain(), s.address());
    }
    else if (isTokenId(s)) {
        // otherwise TokenId
        chain = s.chain;
        address = s.address.toNative(s.chain);
    }
    else {
        throw new Error("Invalid nativeChainAddress parameters");
    }
    return { chain, address };
}
export function isTransactionIdentifier(thing) {
    return thing.chain !== undefined && thing.txid !== undefined;
}
export function buildConfig(n) {
    const cc = chains
        .map((c) => {
        const platform = chainToPlatform(c);
        let nativeChainId = "";
        try {
            nativeChainId = nativeChainIds.networkChainToNativeChainId.get(n, c);
        }
        catch { }
        return {
            key: c,
            platform,
            network: n,
            chainId: toChainId(c),
            finalityThreshold: finality.finalityThreshold.get(c) ?? 0,
            blockTime: finality.blockTime(c),
            contracts: getContracts(n, c),
            nativeTokenDecimals: decimals.nativeDecimals(platform),
            nativeChainId,
            explorer: explorer.explorerConfigs(n, c),
            rpc: rpc.rpcAddress(n, c),
        };
    })
        .reduce((acc, curr) => {
        return { ...acc, [curr.key]: curr };
    }, {});
    return cc;
}
//# sourceMappingURL=types.js.map